robotpy-commands-v1
===================

Python wrappers around the old WPILib commands library. 

The API is expected to match the pure python API prior to 2020. If there are
differences, please report them as a bug and we'll address them or make a note
in this README.

* 2020.1.2.2 changed various methods to no longer have a preceding underscore